@@ -6,7 +6,7 @@ import { IDocumentManager } from '@jupyterlab/docmanager';
 import { ToolbarButton } from '@jupyterlab/apputils';
 import { IDisposable, DisposableDelegate } from '@lumino/disposable';
 import { IMainMenu } from '@jupyterlab/mainmenu';
-import { getFileContents, loadLabContents } from '../tools';
+import { getFileContents, getLabFilePath, loadLabContents, parseJwt } from '../tools';
 import { axiosHandler, postLabModel } from '../handler';
 import { Globals } from '../config';
 import { ATLAS_TOKEN } from '../config';
@@ -79,6 +79,7 @@ export class ButtonExtension
 async function activate(
   app: JupyterFrontEnd,
   mainMenu: IMainMenu,
+  docManager: IDocumentManager
 ) {
 
   console.log("Activated skillsnetwork-authoring-extension button plugin!");
@@ -89,38 +90,20 @@ async function activate(
   // Add the Publish widget to the lab environment
   app.docRegistry.addWidgetExtension('Notebook', new ButtonExtension());
 
-  // TO DO: Change logic so that we check if the file exists first before trying to open it...
-  // TO DO: Add logic to rename the default file opened to lab's name
-  console.log('where', Globals.AUTHOR_ENV);
-  console.log(Globals.PY_KERNEL_NAME, Globals.LAB_TOOL_TYPE);
+  console.log('Detected your environment as: ', Globals.AUTHOR_ENV);
+  //console.log(Globals.PY_KERNEL_NAME, Globals.LAB_TOOL_TYPE);
+
+  const parsedToken = parseJwt(token)
+  const labFilename = getLabFilePath(parsedToken);
+
   // Only try to load up a notebook when author is using the browser tool (not in local)
   if (Globals.AUTHOR_ENV === 'browser'){
     // Attempt to open the lab
-    await app.commands.execute('docmanager:open', {
-      path: 'Untitled.ipynb',
-      kernel: { name: Globals.PY_KERNEL_NAME } })
-    // The lab was created in a previous session, open up the existing lab
-    .then(async (widget) => {
-      console.log('Successfully got existing file');
-      // Only try to load up lab when author is not in local authoring env
-      // TODO: Refactor this and make it better :')
-        // Load the contents of the lab into the notebook
-        await loadLabContents(widget, axiosHandler(token), Globals.AUTHOR_ENV)
-          .then(()=> widget.show())
-          .catch();
-    })
-    // This is the user's first session, create the lab first and open it for them
-    .catch(async () => {
-      console.log('Could not open file. Creating new file.');
-      // Create a new notebook with Panel
-      const nbPanel: NotebookPanel = await app.commands.execute(
-        'notebook:create-new',
-        { kernelName: Globals.PY_KERNEL_NAME, activate: true }
-      );
-      console.log('Created a new file!');
-        await loadLabContents(nbPanel, axiosHandler(token), Globals.AUTHOR_ENV)
-        .then(() => nbPanel.show());
-    });
+    let widget = await docManager.createNew(labFilename, 'notebook', { name:  Globals.PY_KERNEL_NAME} ) as any;
+    await loadLabContents(widget, axiosHandler(token), Globals.AUTHOR_ENV);
+      widget.context.ready.then(() => {
+        docManager.openOrReveal(labFilename, 'default', { name:  Globals.PY_KERNEL_NAME });
+      });
   }
 }
 
