@@ -8,6 +8,7 @@ import {
 } from './config';
 import axios from 'axios';
 import { Globals } from './config';
+import { source } from './config';
 
 export const axiosHandler = (lab_token?: string): AxiosInstance => {
   if (lab_token) Globals.TOKEN = lab_token;
@@ -65,6 +66,8 @@ export const postLabModel = async (
     await axiosHandler
       .post('v1/labs', {
         body: labModel
+      },{
+        cancelToken: source.token,
       })
       .then(res => {
         console.log('SUCCESSFULLY PUSHED', res);
