@@ -2,17 +2,18 @@ import { JupyterFrontEnd, JupyterFrontEndPlugin } from '@jupyterlab/application'
 import { IMainMenu } from '@jupyterlab/mainmenu';
 import { Menu, Widget } from '@lumino/widgets';
 import { Dialog, showDialog } from '@jupyterlab/apputils';
-import { INotebookTracker, NotebookPanel } from '@jupyterlab/notebook';
+import { INotebookTracker, NotebookPanel,   } from '@jupyterlab/notebook';
+import { IDocumentManager } from '@jupyterlab/docmanager';
 import { show_spinner } from '../dialog';
-import { loadLabContents } from '../tools';
+import { getLabFilePath, loadLabContents, parseJwt } from '../tools';
 import { axiosHandler } from '../handler';
 import { Globals } from '../config';
 
 export const menu: JupyterFrontEndPlugin<void> = {
   id: 'skillsnetwork-authoring-extension:menu',
   autoStart: true,
-  requires: [IMainMenu, INotebookTracker],
-  activate: (app: JupyterFrontEnd, mainMenu: IMainMenu, notebookTracker: INotebookTracker) => {
+  requires: [IMainMenu, INotebookTracker, IDocumentManager],
+  activate: (app: JupyterFrontEnd, mainMenu: IMainMenu, notebookTracker: INotebookTracker, docManager: IDocumentManager) => {
 
     console.log('Activated skillsnetwork-authoring-extension menu plugin!');
 
@@ -20,7 +21,7 @@ export const menu: JupyterFrontEndPlugin<void> = {
     app.commands.addCommand(editLabFromToken, {
     label: 'Edit a Lab',
     execute: () => {
-      showTokenDialog(notebookTracker);
+      showTokenDialog(notebookTracker, docManager);
     }
     })
 
@@ -37,7 +38,8 @@ export const menu: JupyterFrontEndPlugin<void> = {
     args: {}
     });
 
-    const showTokenDialog = (notebookTracker: INotebookTracker) => {
+    const showTokenDialog = (notebookTracker: INotebookTracker, docManager: IDocumentManager) => {
+
       // Generate Dialog body
       let bodyDialog = document.createElement('div');
       let nameLabel = document.createElement('label');
@@ -54,13 +56,17 @@ export const menu: JupyterFrontEndPlugin<void> = {
       }).then(async result => {
         if (result.button.accept){
           show_spinner('Loading up your lab...');
-          // Open up a blank notebook, set the kernel and load up lab
-          const nbPanel: NotebookPanel = await app.commands.execute(
-            'notebook:create-new',
-            { kernelName: Globals.PY_KERNEL_NAME, activate: true }
-          );
-          console.log('Created a new file!');
-          if (nbPanel === null){
+
+          const token = tokenInput.value
+          //console.log('heres the entered token ', token);
+          const parsedToken = parseJwt(token)
+          //console.log('parsed', parsedToken );
+          const labFilename = getLabFilePath(parsedToken);
+
+          const nbPanel = docManager.createNew(labFilename, 'notebook', { name:  Globals.PY_KERNEL_NAME}) as NotebookPanel;
+
+          console.log('Created a new file!', nbPanel);
+          if (nbPanel === undefined){
             throw Error('Error loading lab')
           }
           nbPanel.show();
