@@ -9,6 +9,8 @@ import { DocumentRegistry } from '@jupyterlab/docregistry';
 import * as nbformat from '@jupyterlab/nbformat';
 import { getLabModel } from './handler';
 import { AxiosInstance } from 'axios';
+import { Buffer } from 'buffer';
+import { Globals } from './config';
 
 export interface ICellData {
   cell_type: string;
@@ -94,6 +96,26 @@ export const loadLabContents = async (widget: NotebookPanel, axiosHandlers: Axio
   widget.content.model = model;
 };
 
+export const parseJwt = (token: string) => {
+  const base64Url = token.split('.')[1];
+  const base64 = base64Url.replace(/-/g, '+').replace(/_/g, '/');
+  // const decoded = atob(base64);
+  const decoded = Buffer.from(base64, 'base64').toString();
+  const jsonPayload = decodeURIComponent(decoded.split('').map(function(c) {
+      return '%' + ('00' + c.charCodeAt(0).toString(16)).slice(-2);
+  }).join(''));
+  return JSON.parse(jsonPayload);
+}
+
+export const getLabFilePath = (jwtparsed: any): string => {
+  let labFilename = jwtparsed.filepath ?? Globals.DEFAULT_LAB_NAME;
+  // Replace labs/ prefix with empty string
+  // TODO: We need a more robust way to do this and not rely on the assumption that the lab is in the labs folder
+  // TODO: This is required as the createNew method will not automatically create the parent directories
+  labFilename = labFilename.replace('labs/', '');
+  return labFilename;
+}
+
 // eslint-disable-next-line @typescript-eslint/quotes
 export const DEFAULT_CONTENT: nbformat.INotebookContent = {
   cells: [
